==> seedsui-react-5.7.30.tgz: package/lib/TreePicker/Tree/utils/getKeywordIds.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
// import getKeywordIdsByPinyin from './getKeywordIdsByPinyin'

// 获取关键字的所有匹配的keys
function getKeywordIds(keyword, flattenTree) {
  if (!keyword || typeof keyword !== 'string') return [];
  var keys = [];
  var _iterator = _createForOfIteratorHelper(flattenTree),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var _node$name;
      var node = _step.value;
      if (node.name && (node === null || node === void 0 ? void 0 : (_node$name = node.name) === null || _node$name === void 0 ? void 0 : _node$name.indexOf(keyword)) !== -1) {
        keys.push(node.id);
      }
    }

    // 如果没有匹配到, 再根据拼音匹配
    /*
    if (keys.length < 1 && keyword && /^[a-zA-Z]+$/.test(keyword)) {
      for (let item of flattenTree) {
        if (getKeywordIdsByPinyin(keyword, item.name)) {
          keys.push(item.id)
          break
        }
      }
    }
    */
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return keys;
}
export default getKeywordIds;

==> seedsui-react-5.8.44.tgz: package/lib/TreePicker/Tree/utils/getKeywordIds.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
// import getKeywordIdsByPinyin from './getKeywordIdsByPinyin'

// 获取关键字的所有匹配的keys
function getKeywordIds(keyword, flattenTree) {
  if (!keyword || typeof keyword !== 'string') return [];
  var keys = [];
  var _iterator = _createForOfIteratorHelper(flattenTree),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var _node$name;
      var node = _step.value;
      if (node.name && (node === null || node === void 0 || (_node$name = node.name) === null || _node$name === void 0 ? void 0 : _node$name.indexOf(keyword)) !== -1) {
        keys.push(node.id);
      }
    }

    // 如果没有匹配到, 再根据拼音匹配
    /*
    if (keys.length < 1 && keyword && /^[a-zA-Z]+$/.test(keyword)) {
      for (let item of flattenTree) {
        if (getKeywordIdsByPinyin(keyword, item.name)) {
          keys.push(item.id)
          break
        }
      }
    }
    */
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return keys;
}
export default getKeywordIds;
